/*
calcphi.c Version 2.2.0
Copyright (C) 2001  dondalah@ripco.com (Dondalah)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to:

	Free Software Foundation, Inc.
	59 Temple Place - Suite 330
	Boston, MA  02111-1307, USA.
*/

#include <math.h>

/* From Hugh Kenner */
/* Geodesic math and how to use it */
/* Berkeley: University of California Press, 1976 */
/* ISBN: 0-520-02924-0 */

/* Equations 12.4, 12.5, and 12.7 */
/* This function calculates the value of phi */
/* based on the positions of x and y in the */
/* symmetry triangle of an icosahedron. */
/* This function is used in a Class I calculation */
/* of a geodesic sphere */

/* Values of x,y,z in the icosacap triangle
   of a 2v geodesic sphere:

   First  digit is x.
   Second digit is y.
   Third  digit is z.

                            0,0,2
                             /\
                           /   \
                         /      \
                       /         \
               0,1,1  ------------  1,0,1
                    / \          / \
                  /    \       /    \
                /       \    /       \
              /          \ /          \
             --------------------------
          0,2,0         1,1,0        2,0,0

*/

double calcphi(x,y)
double x,y;
   {
   double phi,x1,y1;
   double getx(),gety(),getz(),getphi();
   /* Equation 12.4 */
   x1 = getx(x);
   /* Equation 12.5 */
   y1 = gety(x,y);
   /* Equation 12.7 */
   phi = getphi(x1,y1);
   return(phi);
   } /* calcphi */
